diff --git a/dlg_wingui.c b/dlg_wingui.c
index 0190ccb..bc024c7 100644
--- a/dlg_wingui.c
+++ b/dlg_wingui.c
@@ -362,7 +362,7 @@ global_optionsProc(HWND hdlg,
 	switch (wMsg)
 	{
 		case WM_INITDIALOG:
-			SetWindowLongPtr(hdlg, DWLP_USER, lParam); /* save for test etc */ 
+			SetWindowLongPtr(hdlg, DWLP_USER, lParam); /* save for test etc */
 			CheckDlgButton(hdlg, DRV_COMMLOG, globals.commlog);
 #ifndef Q_LOG
 			EnableWindow(GetDlgItem(hdlg, DRV_COMMLOG), FALSE);
@@ -847,7 +847,7 @@ ds_options3Proc(HWND hdlg,
 				case IDC_TEST:
 					memcpy(&tmpInfo, ci, sizeof(tmpInfo));
 					ds_options3_update(hdlg, &tmpInfo);
-					test_connection(hdlg, &tmpInfo, TRUE);
+					test_connection(hdlg, &tmpInfo);
 					break;
 				case ID1STPAGE:
 					ds_options3_update(hdlg, ci);
diff --git a/setup.c b/setup.c
index 9177393..33862c0 100644
--- a/setup.c
+++ b/setup.c
@@ -237,7 +237,7 @@ CenterDialog(HWND hdlg)
 	return;
 }
 
-void test_connection(HANDLE hwnd, ConnInfo *ci, BOOL withDTC);
+void test_connection(HANDLE hwnd, ConnInfo *ci);
 /*-------
  * ConfigDlgProc
  *	Description:	Manage add data source name dialog
@@ -354,7 +354,7 @@ ConfigDlgProc(HWND hdlg,
 					{
 						/* Get Dialog Values */
 						GetDlgStuff(hdlg, &lpsetupdlg->ci);
-						test_connection(lpsetupdlg->hwndParent, &lpsetupdlg->ci, FALSE);
+						test_connection(lpsetupdlg->hwndParent, &lpsetupdlg->ci);
 						return TRUE;
 					}
 					break;
@@ -395,7 +395,7 @@ ConfigDlgProc(HWND hdlg,
 	return FALSE;
 }
 
-void test_connection(HANDLE hwnd, ConnInfo *ci, BOOL withDTC)
+void test_connection(HANDLE hwnd, ConnInfo *ci)
 {
 	EnvironmentClass *env = EN_Constructor();
 	ConnectionClass *conn = NULL;
@@ -430,6 +430,11 @@ void test_connection(HANDLE hwnd, ConnInfo *ci, BOOL withDTC)
 #endif /* UNICODE_SUPPORT */
 	if (CC_connect(conn, NULL) > 0)
 	{
+#ifdef _HANDLE_ENLIST_IN_DTC_
+		HRESULT	res;
+		void *pObj = NULL;
+#endif /* _HANDLE_ENLIST_IN_DTC_ */
+
 		if (CC_get_errornumber(conn) != 0)
 		{
 			CC_get_error(conn, &errnum, &emsg);
@@ -440,33 +445,30 @@ void test_connection(HANDLE hwnd, ConnInfo *ci, BOOL withDTC)
 			strncpy_null(szMsg, "Connection successful", sizeof(szMsg));
 		}
 		emsg = szMsg;
-		if (withDTC)
-		{
-			HRESULT	res;
-			void *pObj = NULL;
 
-			pObj = CALL_GetTransactionObject(&res);
-			if (NULL != pObj)
+#ifdef _HANDLE_ENLIST_IN_DTC_
+		pObj = CALL_GetTransactionObject(&res);
+		if (NULL != pObj)
+		{
+			SQLRETURN ret = PGAPI_SetConnectAttr(conn, SQL_ATTR_ENLIST_IN_DTC, (SQLPOINTER) pObj, 0);
+			if (SQL_SUCCEEDED(ret))
 			{
-				SQLRETURN ret = PGAPI_SetConnectAttr(conn, SQL_ATTR_ENLIST_IN_DTC, (SQLPOINTER) pObj, 0);
-				if (SQL_SUCCEEDED(ret))
-				{
-					PGAPI_SetConnectAttr(conn, SQL_ATTR_ENLIST_IN_DTC, SQL_DTC_DONE, 0);
-					snprintf(szMsg, sizeof(szMsg), "%s\nenlistment was successful\n", szMsg);
-				}
-				else
-				{
-					char *dtcerr = NULL;
+				PGAPI_SetConnectAttr(conn, SQL_ATTR_ENLIST_IN_DTC, SQL_DTC_DONE, 0);
+				snprintf(szMsg, sizeof(szMsg), "%s\nenlistment was successful\n", szMsg);
+			}
+			else
+			{
+				char *dtcerr = NULL;
 
-					CC_get_error(conn, &errnum, &dtcerr);
-					if (NULL != dtcerr)
-						snprintf(szMsg, sizeof(szMsg), "%s\nMSDTC error:%s", emsg, dtcerr);
-				}
-				CALL_ReleaseTransactionObject(pObj);
+				CC_get_error(conn, &errnum, &dtcerr);
+				if (NULL != dtcerr)
+					snprintf(szMsg, sizeof(szMsg), "%s\nMSDTC error:%s", emsg, dtcerr);
 			}
-			else if (FAILED(res))
-				snprintf(szMsg, sizeof(szMsg), "%s\nDistibuted Transaction enlistment error %x", emsg, res);
+			CALL_ReleaseTransactionObject(pObj);
 		}
+		else if (FAILED(res))
+			snprintf(szMsg, sizeof(szMsg), "%s\nDistibuted Transaction enlistment error %x", emsg, res);
+#endif /* _HANDLE_ENLIST_IN_DTC_ */
 	}
 	else
 	{
diff --git a/win_setup.h b/win_setup.h
index c7cf8b0..1e6e844 100644
--- a/win_setup.h
+++ b/win_setup.h
@@ -25,6 +25,6 @@ void INTFUNC ParseAttributes(LPCSTR lpszAttributes, LPSETUPDLG lpsetupdlg);
 BOOL INTFUNC SetDSNAttributes(HWND hwnd, LPSETUPDLG lpsetupdlg, DWORD *);
 BOOL INTFUNC ChangeDriverName(HWND hwnd, LPSETUPDLG lpsetupdlg, LPCSTR driver_name);
 
-void test_connection(HANDLE hwnd, ConnInfo *ci, BOOL withDTC);
+void test_connection(HANDLE hwnd, ConnInfo *ci);
 
 #endif /* _WIN_SETUP_H__ */
